<?php

namespace Drupal\paragon_gin;

use Drupal\Core\Access\AccessResultAllowed;
use Drupal\Core\Cache\CacheableMetadata;
use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\Core\Menu\LocalTaskManagerInterface;
use Drupal\Core\Render\Element;
use Drupal\Core\Routing\AdminContext;
use Drupal\Core\Routing\RouteMatchInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

class Alter {

  public function layoutBuilderBrowser (array &$build, array $context) {
    // Remove search because it doesn't work. (fix this soon)
    unset($build['filter']);

    // Add toggle for list and icon view.
    $toggle_enabled = (bool) theme_get_setting('show_lb_toggle', 'gin');
    $default_view = $toggle_enabled ? 'icon' : 'list';
    if ($toggle_enabled) {
      $build['view_options'] = [
        '#weight' => -1,
        '#theme' => "paragon_gin_lb_browser_toggle",
      ];
    }

    $categories = Element::children($build['block_categories']);

    foreach ($categories as $category) {
      $build['block_categories'][$category]['links']['#prefix'] = "<div data-view='{$default_view}' class='paragon-gin-browser-wrapper'>";
      $build['block_categories'][$category]['links']['#suffix'] = "</div>";

      $links = Element::children($build['block_categories'][$category]['links']);

      foreach ($links as $index) {
        $settings = $build['block_categories'][$category]['links'][$index]['link'];
        // Check if Layout Builder Browser Block Library is installed.
        $has_browse_link = isset($build['block_categories'][$category]['links'][$index]['#browse_link']);
        if ($has_browse_link) {
          $settings = $build['block_categories'][$category]['links'][$index];
        }
        // We need to overwrite the render array for the 'Add block' link.
        $render_array = [
          '#theme' => 'paragon_gin_lb_browser_block',
          '#label' => $settings['#title']['label']
        ];
        if (isset($settings['#title']['description'])) {
          $render_array['#description'] = $settings['#title']['description'];
        }
        if (isset($settings['#title']['image'])) {
          $render_array['#image'] = $settings['#title']['image'];
        }
        if ($has_browse_link) {
          // Wrap the anchor tag in a div.
          $build['block_categories'][$category]['links'][$index]['#title'] = $render_array;
          $build['block_categories'][$category]['links'][$index]['#prefix'] = "<div class='layout-builder-browser-block-item'>";
          $build['block_categories'][$category]['links'][$index]['#suffix'] = "</div>";
        } else {
          $render_array = array_merge($render_array, $settings);
          // Do not overwrite the link directly.
          // It will break layout builder modal if installed.
          $build['block_categories'][$category]['links'][$index]['link']['#title'] = $render_array;
        }
      }
    }
    // Attach the CSS/JS.
    $build['#attached']['library'][] = 'paragon_gin/layout-builder-browser';
    $build['#attached']['drupalSettings']['paragon_gin']['default_view'] = $default_view;
  }

  public function pageAttachmentsAlter(array &$attachments) {
    $route_name = \Drupal::routeMatch()->getRouteName();
    if ($route_name !== NULL && preg_match('/^(layout_builder\.([^.]+\.)?)/', $route_name)) {
      $attachments['#attached']['library'][] = 'paragon_gin/layout-builder-improvements';
    }
  }
}
