<?php

namespace Drupal\paragon_gin;

use Drupal\Core\Access\AccessResultAllowed;
use Drupal\Core\Cache\CacheableMetadata;
use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Menu\LocalTaskManagerInterface;
use Drupal\Core\Render\Element;
use Drupal\Core\Routing\AdminContext;
use Drupal\Core\Routing\RouteMatchInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

class FormAlter {
  /**
   * Implements hook_form_alter().
   */
  public function form(&$form, FormStateInterface $form_state, $form_id) {
    switch ($form_id) {
      case 'node_landing_page_layout_builder_form':
      case 'node_system_page_layout_builder_form':
        $revision_information_form = $form['revision_information'];
        $moderation_state_form = $form['moderation_state'];
        $form['actions']['moderation_state'] = $moderation_state_form;

        // When using the moderation_sidebar module, let's avoid redundant
        // clutter and remove moderation state from the vanilla LB display.
        if (isset($form['moderation_state'])) {
          $form['moderation_state']['#type'] = 'hidden';
        }
        if (isset($form['revision_information'])) {
          $form['revision_information']['#access'] = FALSE;
        }
        break;

      case 'layout_builder_add_block':
      case 'layout_builder_update_block':
        // Only alter the block configuration forms for inline or reusable
        // block_content entity blocks, since they are primarily
        // the ones afflicted with the conflict described above.
        $is_reusable_block_content = $form['settings']['provider']['#value'] === 'layout_builder';
        $is_inline_block = isset($form['settings']['block_form']['#block']) && $form['settings']['block_form']['#block'] instanceof BlockContentInterface;
        if (!$is_reusable_block_content && !$is_inline_block) {
          return;
        }

        // Hide the label of the block placement and provide a default value if it
        // is empty.
        if (empty($form['settings']['label']['#default_value'])) {
          $form['settings']['label']['#default_value'] = t('Inline block');
        }

        // Default to hiding the label of the block.
        $form['settings']['label_display']['#default_value'] = FALSE;
        $form['settings']['label_display']['#type'] = 'value';

        array_unshift($form['#submit'], [$this, 'updateTitle']);
        break;
    }
  }

  /**
   * Implements hook_form_FORM_ID_alter().
   *
   * Add a checkbox to toggle the icon and list view in the layout builder.
   */
  public function systemThemeSettings(&$form, $form_state) {
    if ($form['var']['#value'] === 'theme_gin_settings' && isset($form['custom_settings'])) {
      $form['custom_settings']['show_lb_toggle'] = [
        '#type' => 'checkbox',
        '#description' => t('Check this box to show the icon and list toggle in the Layout Builder.'),
        '#title' => t('Show Icon and List toggle in Layout Builder'),
        '#default_value' => theme_get_setting('show_lb_toggle', 'gin'),
      ];
    }
  }

  public function updateTitle(&$form, FormStateInterface $form_state) {
    // Set the title of the block to the block type and the
    // field_heading if its available.
    $values = $form_state->getValue('settings');
    $type = $form['settings']['admin_label']['#plain_text'];

    if (array_key_exists('field_heading', $values['block_form'])) {
      $heading = strip_tags($values['block_form']['field_heading'][0]['value']);
      $values['label'] = substr($type . ' - ' . $heading, 0, 255);
    } else {
      $values['label'] = $type;
    }
    $form_state->setValue('settings', $values);
  }
}
